struct LocalStatus {
box_pointee_assignment: Option<(StmtLoc, Place)>,
ambiguous: bool,
used_outside_derefs: bool,
}Fields
box_pointee_assignment: Option<(StmtLoc, Place)>Whether that local is the target of the special transmute statement we’re looking for.
Stores the *b where b is the Box.
ambiguous: boolWhether that local is the target of more than one such special transmute.
used_outside_derefs: boolWhether that local is ever used outside of a deref projection (apart from the initial assignment).
Implementations
Sourceimpl LocalStatus
impl LocalStatus
fn rewritable_box_pointee(&self) -> Option<&(StmtLoc, Place)>